OC.L10N.register(
    "core",
    {
    "Please select a file." : "Izberite datoteko",
    "File is too big" : "Datoteka je prevelika",
    "Invalid file provided" : "Predložena je neveljavna datoteka",
    "No image or file provided" : "Ni podane datoteke ali slike",
    "Unknown filetype" : "Neznana vrsta datoteke",
    "Invalid image" : "Neveljavna slika",
    "An error occurred. Please contact your admin." : "Prišlo je do napake. Stopite v stik s skrbnikom sistema.",
    "No temporary profile picture available, try again" : "Na voljo ni nobene začasne slike za profil. Poskusite znova.",
    "No crop data provided" : "Ni podanih podatkov obreza",
    "No valid crop data provided" : "Navedeni so neveljavni podatki obrez slike",
    "Crop is not square" : "Obrez ni pravokoten",
    "Could not reset password because the token is invalid" : "Ni mogoče ponastaviti gesla, ker je žeton neveljaven",
    "Could not reset password because the token expired" : "Ni mogoče ponastaviti gesla, ker je žeton potekel",
    "Could not reset password because the token does not match" : "Ni mogoče ponastaviti gesla, ker žeton ni skladen",
    "%s password changed successfully" : "Geslo %s je uspešno spremenjeno",
    "%s password reset" : "Ponastavitev gesla %s",
    "Couldn't send reset email. Please contact your administrator." : "Ni mogoče nastaviti elektronskega naslova za ponastavitev. Stopite v stik s skrbnikom sistema.",
    "Upload only" : "Le pošiljanje",
    "Preparing update" : "Pripravljanje posodobitve",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Opozorilo popravila:",
    "Repair error: " : "Napaka popravila:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Posodobitev sistema je treba izvesti prek ukazne vrstice, ker je nastavitev samodejne posodobitve v config.php onemogočena.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Poteka preverjanje razpredelnice %s",
    "Turned on maintenance mode" : "Vzdrževalni način je omogočen",
    "Turned off maintenance mode" : "Vzdrževalni način je onemogočen",
    "Maintenance mode is kept active" : "Vzdrževalni način je še vedno dejaven",
    "Updating database schema" : "Poteka posodabljanje sheme podatkovne zbirke",
    "Updated database" : "Posodobljena podatkovna zbirka",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Poteka preverjanje, ali je shemo podatkovne zbirke mogoče posodobiti (zaradi velikosti je lahko opravilo dolgotrajno).",
    "Checked database schema update" : "Izbrana posodobitev sheme podatkovne zbirke",
    "Checking updates of apps" : "Poteka preverjanje za posodobitve programov",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Poteka preverjanje, ali je shemo podatkovne zbirke za %s mogoče posodobiti (trajanje posodobitve je odvisno od velikosti zbirke).",
    "Checked database schema update for apps" : "Izbrana posodobitev sheme podatkovne zbirke za programe",
    "Updated \"%s\" to %s" : "Datoteka »%s« je posodobljena na %s",
    "Set log level to debug" : "Nastavi raven beleženja za razhroščevanje",
    "Reset log level" : "Počisti raven beleženja",
    "Starting code integrity check" : "Začenjanje preverjanja stanja kode",
    "Finished code integrity check" : "Končano preverjanje stanja kode",
    "%s (3rdparty)" : "%s (zunanje)",
    "%s (incompatible)" : "%s (neskladno)",
    "Following apps have been disabled: %s" : "Navedeni programi so onemogočeni: %s",
    "Already up to date" : "Sistem je že posodobljen",
    "Sunday" : "nedelja",
    "Monday" : "ponedeljek",
    "Tuesday" : "torek",
    "Wednesday" : "sreda",
    "Thursday" : "četrtek",
    "Friday" : "petek",
    "Saturday" : "sobota",
    "Sun." : "ned",
    "Mon." : "pon",
    "Tue." : "tor",
    "Wed." : "sre",
    "Thu." : "čet",
    "Fri." : "pet",
    "Sat." : "sob",
    "Su" : "Ne",
    "Mo" : "Po",
    "Tu" : "To",
    "We" : "Sr",
    "Th" : "Če",
    "Fr" : "Pe",
    "Sa" : "So",
    "January" : "januar",
    "February" : "februar",
    "March" : "marec",
    "April" : "april",
    "May" : "maj",
    "June" : "junij",
    "July" : "julij",
    "August" : "avgust",
    "September" : "september",
    "October" : "oktober",
    "November" : "november",
    "December" : "december",
    "Jan." : "jan",
    "Feb." : "feb",
    "Mar." : "mar",
    "Apr." : "apr",
    "May." : "maj",
    "Jun." : "jun",
    "Jul." : "jul",
    "Aug." : "avg",
    "Sep." : "sep",
    "Oct." : "okt",
    "Nov." : "nov",
    "Dec." : "dec",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Med preverjanjem celovitosti kode je prišlo do napak. Več podrobnosti …</a>",
    "Settings" : "Nastavitve",
    "Problem loading page, reloading in 5 seconds" : "Napaka nalaganja strani! Poskus ponovnega nalaganja bo izveden čez 5 sekund.",
    "Saving..." : "Poteka shranjevanje ...",
    "Dismiss" : "Opusti",
    "seconds ago" : "pred nekaj sekundami",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Povezava za ponastavitev gesla je bila poslana na naveden elektronski naslov. V kolikor sporočila ne dobite v kratkem, preverite tudi mapo neželene pošte.<br> Če sporočila ni niti v tej mapi, stopite v stik s skrbnikom.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Datoteke so šifrirane. Če niste omogočili obnovitvenega ključa, po ponastavitvi gesla ne bo mogoč dostop do datotek.<br />V primeru, da niste prepričani, kaj storiti, stopite v stik s skrbnikom sistema.<br />Ali ste prepričani, da želite nadaljevati?",
    "I know what I'm doing" : "Vem, kaj delam!",
    "Password can not be changed. Please contact your administrator." : "Gesla ni mogoče spremeniti. Stopite v stik s skrbnikom.",
    "No" : "Ne",
    "Yes" : "Da",
    "Choose" : "Izbor",
    "Error loading file picker template: {error}" : "Napaka nalaganja predloge izbirnika datotek: {error}",
    "Ok" : "V redu",
    "Error loading message template: {error}" : "Napaka nalaganja predloge sporočil: {error}",
    "read-only" : "le za branje",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} spor datotek","{count} spora datotek","{count} spori datotek","{count} sporov datotek"],
    "One file conflict" : "En spor datotek",
    "New Files" : "Nove datoteke",
    "Already existing files" : "Obstoječe datoteke",
    "Which files do you want to keep?" : "Katare datoteke želite ohraniti?",
    "If you select both versions, the copied file will have a number added to its name." : "Če izberete obe različici, bo k imenu na novo kopirane datoteke dodana številka.",
    "Cancel" : "Prekliči",
    "Continue" : "Nadaljuj",
    "(all selected)" : "(vse izbrano)",
    "({count} selected)" : "({count} izbranih)",
    "Error loading file exists template" : "Napaka nalaganja predloge obstoječih datotek",
    "Very weak password" : "Zelo šibko geslo",
    "Weak password" : "Šibko geslo",
    "So-so password" : "Slabo geslo",
    "Good password" : "Dobro geslo",
    "Strong password" : "Odlično geslo",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Spletni stražnik še ni ustrezno nastavljen in ne omogoča usklajevanja, saj je vmesnik WebDAV videti okvarjen.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Spletni strežnik ni ustrezno nastavljen za razreševanje \"{url}\". Več pdorobnosti je zapisanih v <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaciji</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Strežnik je brez vzpostavljene internetne povezave. To pomeni, da priklapljanje zunanjih diskov,  opozorila za posodobitve in namestitve programske opreme iz drugih virov, niso mogoče. Za popolno delovanje OwnCloud je nujna delujoča internetna povezava.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Ni nastavljenega predpomnilnika. Za izboljšanje hitrosti delovanja je treba predpomnilnik memcache, če je na voljo, ustrezno nastaviti. Več podrobnosti je na voljo v <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaciji</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Iz varnostnih razlogov je priporočljivo nastaviti dovoljenja ukaza /dev/urandom za branje prek PHP. Več podrobnosti je zavedenih v <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaciji<-a>",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Trenutno je zagnana različica PHP {version}. Priporočljivo je posodobiti sistem na najnovejšo različico in s tem namestiti <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">funkcijske in varnostne posodobitve delovanja, ki jih zagotavlja skupnost PHP</a>. Pakete je priporočljivo posodobiti takoj, ko so na voljo za nameščeno distribucijo.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Nastavitve glav posredniškega strežnika so nepravilne, ali pa poskušate dostopiti ownCloud prek varne posredniške povezave. V kolikor slednje ne drži, je problem varnostne narave, ki lahko omogoči napadalcu javljanje z izmišljenega naslova IP.  Več podrobnosti je zabeleženih v <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaciji</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Predpomnilnik memcached je nastavljen kot porazdeljen predpomnilnik, vendar pa je nameščen napačen modul PHP \"memcache\". Modul \\OC\\Memcache\\Memcached podpirao le \"memcached\", ne pa tudi \"memcache\". Več podrobnosti za oba modula je zapisanih  <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">na wiki straneh</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Nekatere datoteke ne opravijo preizkusa celovitosti. Več podrobnosti o težavi je opisanih v <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaciji</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Seznam neveljavnih datotek …</a> / <a href=\"{rescanEndpoint}\">Ponovni preizkus …</a>)",
    "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Podatkovna mapa in datoteke so najverjetneje dostopni prek Interneta, ker datoteka .htaccess ni ustrezno nastavljena. Priporočljivo je nastaviti spletni strežnik tako, da dostop prek zunanjega omrežja ni mogoč, ali pa tako, da podatkovna mapa ni znotraj korenske mape strežnika.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP glava \"{header}\" ni nastavljena na pričakovano vrednost \"{expected}\". To je lahko varnostna težava, zato je nastavitve priporočeno popraviti.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "Nastavitev časovne omejitve HTTP glave Strict-Transport-Security ni nastavljena na vsaj \"{seconds}\" sekund. Za večjo varnost je priporočljivo nastaviti vrednost HSTS po <a href=\"{docUrl}\" rel=\"noreferrer\">varnostnih priporočilih</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Do spletišča je omogočen dostop prek protokola HTTP. Priporočljivo je omogočiti podporo za varni protokol HTTPS. Več podrobnosti je zapisanih med <a href=\"{docUrl}\">varnostnimi namigi</a>.",
    "Shared" : "V souporabi",
    "Shared with {recipients}" : "V souporabi z {recipients}",
    "Error" : "Napaka",
    "Error while sharing" : "Napaka med souporabo",
    "Error while unsharing" : "Napaka med odstranjevanjem souporabe",
    "The public link will expire no later than {days} days after it is created" : "Javna povezava bo potekla {days} dni po ustvarjanju.",
    "Expiration" : "Datum preteka",
    "Expiration date is required" : "Zahtevan je datum preteka veljavnosti",
    "Delete {link}" : "Izbriši povezavo {link}",
    "Remove link" : "Odstrani povezavo",
    "Link" : "Povezava",
    "Create public link" : "Ustvari javno povezavo",
    "Edit" : "Uredi",
    "Remove" : "Odstrani",
    "Copy to clipboard" : "Kopiraj v odložišče",
    "Social share" : "Objava prek socialnega omrežja",
    "There are currently no link shares, you can create one" : "Trenutno ni povezav za souporabo. Morda lahko povezave ustvarite.",
    "Anyone with the link has access to the file/folder" : "Vsak, ki ima povezavo ima dostop do datoteke ali mape",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Možnost ni podprta!",
    "Press ⌘-C to copy." : "Pritisnite tipki ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite tipki Ctrl-C za kopiranje.",
    "Choose a password" : "Izbor gesla",
    "Password required" : "Zahtevano je geslo",
    "Link name" : "Naziv povezave",
    "Name" : "Ime",
    "Filename" : "Ime datoteke",
    "Password" : "Geslo",
    "Edit link share: {name}" : "Uredi povezavo za souporabo: {name}",
    "Create link share: {name}" : "Ustvari povezavo za souporabo: {name}",
    "Share" : "Souporaba",
    "Save" : "Shrani",
    "Remove password" : "Odstrani geslo",
    "Share to Twitter. Opens in a new window." : "Objavi povezavo na Twitter (odpre v novem oknu).",
    "Share to Facebook. Opens in a new window." : "Objavi povezavo na Facebook (odpre se v novem oknu).",
    "Share to Diaspora. Opens in a new window." : "Objavi povezavo na Diasporo (odpre v novem oknu).",
    "Share via email. Opens your mail client." : "Objavi povezavo prek elektronske pošte (odpre v oknu odjemalca).",
    "Email link to person" : "Posreduj povezavo po elektronski pošti",
    "Send link via email" : "Pošlji povezavo prek elektronske pošte",
    "Sending" : "Pošiljanje",
    "Shared with you and the group {group} by {owner}" : "V souporabi z vami in skupino {group}. Lastnik je {owner}.",
    "Shared with you by {owner}" : "V souporabi z vami. Lastnik je {owner}.",
    "group" : "skupina",
    "notify by email" : "obvesti po elektronski pošti",
    "Unshare" : "Prekliči souporabo",
    "can share" : "lahko omogoči souporabo",
    "can edit" : "lahko ureja",
    "create" : "ustvari",
    "change" : "sprememba",
    "delete" : "izbriše",
    "access control" : "nadzor dostopa",
    "Could not unshare" : "Ni mogoče prekiniti souporabe",
    "Share details could not be loaded for this item." : "Podrobnosti souporabe za te predmet ni mogoče naložiti.",
    "No users or groups found for {search}" : "Ni najdenih uporabnikov ali skupin za {search}",
    "No users found for {search}" : "Ni uporabnikov, skladnih z iskalnim nizom {search}",
    "An error occurred. Please try again" : "Prišlo je do napake. Poskusite znova.",
    "User" : "Uporabnik",
    "Group" : "Skupina",
    "User and Groups" : "Uporabnik in skupine",
    "Public Links" : "Javne povezave",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Souporaba z uporabniki, ki so na drugih oblakih ownCloud s povezavo uporabnik@domena.si/owncloud",
    "Share with users…" : "Omogoči souporabo z ...",
    "Share with users or groups…" : "Souporaba z uporabniki ali skupinami ...",
    "Error removing share" : "Napaka odstranjevanja souporabe",
    "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
    "restricted" : "omejeno",
    "invisible" : "nevidno",
    "({scope})" : "({scope})",
    "Rename" : "Preimenuj",
    "Delete" : "Izbriši",
    "Collaborative tags" : "Oznake za sodelovalno souporabo",
    "The object type is not specified." : "Vrsta predmeta ni podana.",
    "Enter new" : "Vnesite novo",
    "Add" : "Dodaj",
    "Edit tags" : "Uredi oznake",
    "Error loading dialog template: {error}" : "Napaka nalaganja predloge pogovornega okna: {error}",
    "No tags selected for deletion." : "Ni izbranih oznak za izbris.",
    "unknown text" : "neznano besedilo",
    "Hello world!" : "Pozdravljen svet!",
    "sunny" : "sončno",
    "Hello {name}, the weather is {weather}" : "Pozdravljeni, {name}, vreme je {weather}",
    "Hello {name}" : "Pozdravljeni, {name}",
    "new" : "novo",
    "_download %n file_::_download %n files_" : ["prejmi %n datoteko","prejmi %n datoteki","prejmi %n datoteke","prejmi %n datotek"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Trenutno se izvaja posodobitev sistema. Priporočljivo je počakati, saj se lahko opravilo, če stran zapustite, prekine.",
    "Updating to {version}" : "Posodabljanje na različico {version}",
    "An error occurred." : "Prišlo je do napake.",
    "Please reload the page." : "Stran je treba ponovno naložiti",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Posodobitev je spodletela. Za več podrobnosti o napaki je <a href=\"{url}\">objavljenih na forumu</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Posodobitev je spodletela uspela. Pošljite poročilo o napaki razvijalcem sistema <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud</a>.",
    "The update was successful. There were warnings." : "Posodobitev je uspešno končana, vendar z nekaj opozorili.",
    "The update was successful. Redirecting you to ownCloud now." : "Posodobitev je uspešno končana. Stran bo preusmerjena na oblak ownCloud.",
    "Searching other places" : "Iskanje drugih mest",
    "No search results in other folders" : "Iskanje po drugih mapah ni vrnilo rezultata",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} rezultat v drugih mapah","{count} rezultata v drugih mapah","{count} rezultatov v drugih mapah","{count} rezultatov v drugih mapah"],
    "Personal" : "Osebno",
    "Users" : "Uporabniki",
    "Apps" : "Programi",
    "Admin" : "Skrbništvo",
    "Help" : "Pomoč",
    "Access forbidden" : "Dostop je prepovedan",
    "File not found" : "Datoteke ni mogoče najti",
    "The specified document has not been found on the server." : "Določenega dokumenta na strežniku ni mogoče najti.",
    "You can click here to return to %s." : "S klikom na povezavo boste vrnjeni na %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Pozdravljeni,\n\noseba %s vam je omogočila souporabo %s.\nVir si lahko ogledate: %s\n\n",
    "The share will expire on %s." : "Povezava souporabe bo potekla %s.",
    "Cheers!" : "Lep pozdrav!",
    "Internal Server Error" : "Notranja  napaka strežnika",
    "The server encountered an internal error and was unable to complete your request." : "Prišlo je do notranje napake, zato ni mogoče končati zahteve.",
    "Technical details" : "Tehnične podrobnosti",
    "Remote Address: %s" : "Oddaljen naslov: %s",
    "Request ID: %s" : "ID zahteve: %s",
    "Type: %s" : "Vrsta: %s",
    "Code: %s" : "Koda: %s",
    "Message: %s" : "Sporočilo: %s",
    "File: %s" : "Datoteka: %s",
    "Line: %s" : "Vrstica: %s",
    "Trace" : "Sledenje povezav",
    "Imprint" : "Natis",
    "Create an <strong>admin account</strong>" : "Ustvari <strong>skrbniški račun</strong>",
    "Username" : "Uporabniško ime",
    "Storage & database" : "Shramba in podatkovna zbirka",
    "Data folder" : "Podatkovna mapa",
    "Configure the database" : "Nastavi podatkovno zbirko",
    "Only %s is available." : "Le %s je na voljo.",
    "Install and activate additional PHP modules to choose other database types." : "Namestite in omogočite dodatne module PHP za izbor drugih vrst podatkovnih zbirk.",
    "For more details check out the documentation." : "Za več podrobnosti preverite dokumentacijo.",
    "Database user" : "Uporabnik podatkovne zbirke",
    "Database password" : "Geslo podatkovne zbirke",
    "Database name" : "Ime podatkovne zbirke",
    "Database tablespace" : "Razpredelnica podatkovne zbirke",
    "Database host" : "Gostitelj podatkovne zbirke",
    "Performance warning" : "Opozorilo učinkovitosti delovanja",
    "SQLite will be used as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite",
    "For larger installations we recommend to choose a different database backend." : "Za večje namestitve je priporočljivo uporabiti drugo ozadnji program  zbirke podatkov.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Uporaba SQLite ni priporočljiva iz varnostnih razlogov, še posebej če se sistem krajevno usklajuje z namizjem prek odjemalca.",
    "Finish setup" : "Končaj nastavitev",
    "Need help?" : "Ali potrebujete pomoč?",
    "See the documentation" : "Preverite dokumentacijo",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Pozdravljeni,<br><br>uporabnik %s vam je omogočil souporabo <strong>%s</strong>.<br><a href=\"%s\">Oglejte si vsebino!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Program zahteva podporo JavaScript za pravilno delovanje. Med nastavitvami omogočite {linkstart}JavaScript{linkend} in osvežite spletno stran.",
    "Menu" : "Meni",
    "Log out" : "Odjava",
    "Search" : "Poišči",
    "You are trying to access a private link. Please log in first." : "Poskušate odpreti zasebno povezavo. Pred nadaljevanjem se je treba prijaviti.",
    "Server side authentication failed!" : "Overitev s strežnika je spodletela!",
    "Please contact your administrator." : "Stopite v stik s skrbnikom sistema.",
    "An internal error occurred." : "Prišlo je do notranje napake.",
    "Please try again or contact your administrator." : "Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
    "Login" : "Prijava",
    "Username or email" : "Uporabniško ime ali elektronski naslov",
    "Wrong password. Reset it?" : "Napačno geslo. Ali ga želite ponastaviti?",
    "Wrong password." : "Napačno geslo!",
    "Stay logged in" : "Ohrani prijavo",
    "Alternative Logins" : "Druge prijavne možnosti",
    "Use the following link to reset your password: {link}" : "Za ponastavitev gesla uporabite povezavo: {link}",
    "Password changed successfully" : "Geslo je uspešno spremenjeno",
    "New password" : "Novo geslo",
    "Reset password" : "Ponastavi geslo",
    "This ownCloud instance is currently in single user mode." : "Ta seja oblaka ownCloud je trenutno v načinu enega sočasnega uporabnika.",
    "This means only administrators can use the instance." : "To pomeni, da lahko oblak uporabljajo le osebe s skrbniškimi dovoljenji.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Stopite v stik s skrbnikom sistema, če se bo sporočilo še naprej nepričakovano prikazovalo.",
    "Thank you for your patience." : "Hvala za potrpežljivost!",
    "Two-step verification" : "Dvostopenjsko overjanje",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Za račun je omogočena povečana varnost. Račun overite z uporabo drugega faktorja.",
    "Cancel login" : "Prekliči prijavo",
    "Please authenticate using the selected factor." : "Overite z uporabo izbranega faktorja.",
    "An error occurred while verifying the token" : "Prišlo je do napake med preverjanjem žetona",
    "App update required" : "Zahtevana je posodobitev programa",
    "%s will be updated to version %s" : "%s bo posodobljen na različico %s.",
    "These apps will be updated:" : "Posodobljeni bodo naslednji vstavki:",
    "The theme %s has been disabled." : "Tema %s je onemogočena za uporabo.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred nadaljevanjem se prepričajte se, da je ustvarjena varnostna kopija podatkovne zbirke, nastavitvenih datotek in podatkovne mape.",
    "Start update" : "Začni posodobitev",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Za razreševanje časovnih zahtev večjih namestitev lahko uporabite ukaz iz namestitvene mape:",
    "Detailed logs" : "Podrobni dnevniški zapisi",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Za več podrobnosti si oglejte <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentacijo</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v načinu vzdrževanja, kar lahko traja.",
    "This page will refresh itself when the %s instance is available again." : "Stran bo osvežena ko bo %s spet na voljo."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
